@@ -1,5 +1,5 @@
 """Results models."""
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 from pydantic import BaseModel, Field
 
@@ -53,6 +53,10 @@ class Result(BaseModel):
         ...,
         title='list of edge bindings',
     )
+    score: Optional[float] = Field(
+        None,
+        format="float",
+    )
 
     class Config:
         title = 'result'
